/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM calIWcapFreeBusyListener.idl
 */

#ifndef __gen_calIWcapFreeBusyListener_h__
#define __gen_calIWcapFreeBusyListener_h__


#ifndef __gen_calIWcapFreeBusyEntry_h__
#include "calIWcapFreeBusyEntry.h"
#endif

#ifndef __gen_calIWcapCalendar_h__
#include "calIWcapCalendar.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    calIWcapFreeBusyListener */
#define CALIWCAPFREEBUSYLISTENER_IID_STR "4498e0d0-04ec-43a3-92e0-560667696cf3"

#define CALIWCAPFREEBUSYLISTENER_IID \
  {0x4498e0d0, 0x04ec, 0x43a3, \
    { 0x92, 0xe0, 0x56, 0x06, 0x67, 0x69, 0x6c, 0xf3 }}

class NS_NO_VTABLE calIWcapFreeBusyListener : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(CALIWCAPFREEBUSYLISTENER_IID)

  /**
     * Callback receiving free-busy entries.
     *
     * @param rc result code,
     *           e.g. NS_OK or calIWcapErrors.WCAP_CALENDAR_DOES_NOT_EXIST
     * @param requestId request id to distinguish asynchronous requests
     * @param calId a calid or "mailto:rfc822addr"
     * @param count number of free-busy entries
     * @param entries free-busy entries
     */
  /* void onGetFreeBusyTimes (in nsresult rc, in unsigned long requestId, in string calId, in unsigned long count, [array, size_is (count)] in calIWcapFreeBusyEntry entries); */
  NS_IMETHOD OnGetFreeBusyTimes(nsresult rc, PRUint32 requestId, const char *calId, PRUint32 count, calIWcapFreeBusyEntry **entries) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(calIWcapFreeBusyListener, CALIWCAPFREEBUSYLISTENER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_CALIWCAPFREEBUSYLISTENER \
  NS_IMETHOD OnGetFreeBusyTimes(nsresult rc, PRUint32 requestId, const char *calId, PRUint32 count, calIWcapFreeBusyEntry **entries); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_CALIWCAPFREEBUSYLISTENER(_to) \
  NS_IMETHOD OnGetFreeBusyTimes(nsresult rc, PRUint32 requestId, const char *calId, PRUint32 count, calIWcapFreeBusyEntry **entries) { return _to OnGetFreeBusyTimes(rc, requestId, calId, count, entries); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_CALIWCAPFREEBUSYLISTENER(_to) \
  NS_IMETHOD OnGetFreeBusyTimes(nsresult rc, PRUint32 requestId, const char *calId, PRUint32 count, calIWcapFreeBusyEntry **entries) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnGetFreeBusyTimes(rc, requestId, calId, count, entries); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public calIWcapFreeBusyListener
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_CALIWCAPFREEBUSYLISTENER

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, calIWcapFreeBusyListener)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* void onGetFreeBusyTimes (in nsresult rc, in unsigned long requestId, in string calId, in unsigned long count, [array, size_is (count)] in calIWcapFreeBusyEntry entries); */
NS_IMETHODIMP _MYCLASS_::OnGetFreeBusyTimes(nsresult rc, PRUint32 requestId, const char *calId, PRUint32 count, calIWcapFreeBusyEntry **entries)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_calIWcapFreeBusyListener_h__ */
